@@ -1,11 +1,11 @@
 /*****
 * paint.c : XmHTML rendering routines
 *
-* This file Version	$Revision: 1.11 $
+* This file Version	$Revision: 1.11.6.1 $
 *
 * Creation date:		Fri Dec  6 19:50:20 GMT+0100 1996
-* Last modification: 	$Date: 1999/07/29 01:26:29 $
-* By:					$Author: sopwith $
+* Last modification: 	$Date: 2001/10/20 06:52:12 $
+* By:					$Author: kmaraas $
 * Current State:		$State: Exp $
 *
 * Author:				newt
@@ -32,6 +32,11 @@
 /*****
 * ChangeLog 
 * $Log: paint.c,v $
+* Revision 1.11.6.1  2001/10/20 06:52:12  kmaraas
+* 2001-10-20  Kjartan Maraas  <kmaraas@gnome.org>
+*
+* 	* *.*: Apply all the Red Hat patches.
+*
 * Revision 1.11  1999/07/29 01:26:29  sopwith
 *
 *
@@ -1604,13 +1609,8 @@ DrawRule(XmHTMLWidget html, XmHTMLObjectTableElement data)
 	xs = data->x - html->html.scroll_x;
 
 	/* vertical offset */
-#if 0
 	dy = (int)(0.75*(html->html.default_font->height));
-#else
-	dy = 0;
-#endif	
 	ys = data->y - html->html.scroll_y;
-
 	if(data->height)
 	{
 		if(data->y_offset)	/* noshade */
