@@ -62,8 +62,8 @@ struct _GnomeCanvasWidget {
 
 	guint destroy_id;		/* Signal connection id for destruction of child widget */
 
-	int size_pixels : 1;		/* Is size specified in (unchanging) pixels or units (get scaled)? */
-	int in_destroy : 1;		/* Is child widget being destroyed? */
+	guint size_pixels : 1;		/* Is size specified in (unchanging) pixels or units (get scaled)? */
+	guint in_destroy : 1;		/* Is child widget being destroyed? */
 };
 
 struct _GnomeCanvasWidgetClass {
