@@ -60,7 +60,7 @@ gnome_icon_text_info_free (GnomeIconTextInfo *ti)
  * Return value: A newly-created &GnomeIconTextInfo structure.
  */
 GnomeIconTextInfo *
-gnome_icon_layout_text (GdkFont *font, char *text, char *separators, int max_width, int confine)
+gnome_icon_layout_text (GdkFont *font, const gchar *text, const gchar *separators, gint max_width, gboolean confine)
 {
 	GnomeIconTextInfo *ti;
 	GnomeIconTextInfoRow *row;
@@ -241,7 +241,7 @@ gnome_icon_layout_text (GdkFont *font, char *text, char *separators, int max_wid
  */
 void
 gnome_icon_paint_text (GnomeIconTextInfo *ti, GdkDrawable *drawable, GdkGC *gc,
-		       int x, int y, GtkJustification just)
+		       gint x, gint y, GtkJustification just)
 {
 	GList *item;
 	GnomeIconTextInfoRow *row;
