@@ -415,6 +415,10 @@ init_term_with_defaults(struct termios* term)
 #ifdef ECHOKE
 	  | ECHOKE
 #endif
+#ifdef ECHOK
+	  | ECHOK
+#endif
+        | ECHOK
 #ifdef ECHOCTL
 	  | ECHOCTL
 #endif
